==> vst3sdk-docs-3.7.14_build_55-1.0-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.js <==
var namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands =
[
    [ "Debug", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html", [
      [ "ResaveSharedResources", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html#a6d3516ea6749ec229d0d91c271041b15", null ],
      [ "ToggleInlineUIEditor", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html#aa97cc016c6d37184f92601e65795b16e", null ]
    ] ],
    [ "About", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a87cfb23bb2655f7dca7aae3d0a7fef52", null ],
    [ "CloseWindow", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#af2b4508aa3f45b5f6eb6b178223fa566", null ],
    [ "Copy", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a7d56f2c323ba5bd5c64f50a13420e569", null ],
    [ "Cut", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a7ee702fcd7a1b31281e5a011bf2ad0b2", null ],
    [ "Delete", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a2fd20ed62101a42fc55d81003e7aa2a6", null ],
    [ "Help", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a24ab8ebf04dcca392676b1762d7d47d3", null ],
    [ "NewDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a33e1a9b06671ce59afbf377e48fff5e3", null ],
    [ "OpenDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#ac632d635d09463432c86cf581d474c6e", null ],
    [ "Paste", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#aef7b0d40628bf573f33866320010168c", null ],
    [ "Preferences", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a967c621f16dcb5a77c8fc90d52e0500e", null ],
    [ "Quit", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a3a9d4c336f96665174f4ef591b7aeba9", null ],
    [ "Redo", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a6f3189cc7d5e9495153f20bce21ec6ba", null ],
    [ "RevertDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a6165911437965ccf21d61830ae5b98a2", null ],
    [ "SaveDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a41780505cd93155dc30309ae0f34d6fb", null ],
    [ "SaveDocumentAs", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#ab3e27b15eda08bd8df4a1760068df6d2", null ],
    [ "SelectAll", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#acccf1259d0a7d33005f1e36c0afd40f9", null ],
    [ "Undo", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a62845837178d463a6c2165f741a1c043", null ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.js <==
var namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands =
[
    [ "Debug", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html", [
      [ "RecreateView", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html#aad068430fe1739b83dd8404f6e0b782e", null ],
      [ "ResaveSharedResources", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html#a6d3516ea6749ec229d0d91c271041b15", null ],
      [ "ToggleInlineUIEditor", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html#aa97cc016c6d37184f92601e65795b16e", null ]
    ] ],
    [ "About", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a87cfb23bb2655f7dca7aae3d0a7fef52", null ],
    [ "CloseWindow", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#af2b4508aa3f45b5f6eb6b178223fa566", null ],
    [ "Copy", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a7d56f2c323ba5bd5c64f50a13420e569", null ],
    [ "Cut", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a7ee702fcd7a1b31281e5a011bf2ad0b2", null ],
    [ "Delete", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a2fd20ed62101a42fc55d81003e7aa2a6", null ],
    [ "FindNext", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a3295aa1134399e6ce0688502c0603b46", null ],
    [ "FindPrevious", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a25611e9c2b5bd6783fabbb839b646f5b", null ],
    [ "Help", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a24ab8ebf04dcca392676b1762d7d47d3", null ],
    [ "NewDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a33e1a9b06671ce59afbf377e48fff5e3", null ],
    [ "OpenDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#ac632d635d09463432c86cf581d474c6e", null ],
    [ "Paste", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#aef7b0d40628bf573f33866320010168c", null ],
    [ "Preferences", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a967c621f16dcb5a77c8fc90d52e0500e", null ],
    [ "Quit", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a3a9d4c336f96665174f4ef591b7aeba9", null ],
    [ "Redo", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a6f3189cc7d5e9495153f20bce21ec6ba", null ],
    [ "RevertDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a6165911437965ccf21d61830ae5b98a2", null ],
    [ "SaveDocument", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a41780505cd93155dc30309ae0f34d6fb", null ],
    [ "SaveDocumentAs", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#ab3e27b15eda08bd8df4a1760068df6d2", null ],
    [ "SelectAll", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#acccf1259d0a7d33005f1e36c0afd40f9", null ],
    [ "Undo", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html#a62845837178d463a6c2165f741a1c043", null ]
];
